/****************************************************************************
** Meta object code from reading C++ file 'avahi_serviceresolver_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdnssd-5.43.0/src/avahi_serviceresolver_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'avahi_serviceresolver_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface_t {
    QByteArrayData data[18];
    char stringdata0[161];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface_t qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface = {
    {
QT_MOC_LITERAL(0, 0, 43), // "OrgFreedesktopAvahiServiceRes..."
QT_MOC_LITERAL(1, 44, 7), // "Failure"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 5), // "error"
QT_MOC_LITERAL(4, 59, 5), // "Found"
QT_MOC_LITERAL(5, 65, 9), // "interface"
QT_MOC_LITERAL(6, 75, 8), // "protocol"
QT_MOC_LITERAL(7, 84, 4), // "name"
QT_MOC_LITERAL(8, 89, 4), // "type"
QT_MOC_LITERAL(9, 94, 6), // "domain"
QT_MOC_LITERAL(10, 101, 4), // "host"
QT_MOC_LITERAL(11, 106, 9), // "aprotocol"
QT_MOC_LITERAL(12, 116, 7), // "address"
QT_MOC_LITERAL(13, 124, 4), // "port"
QT_MOC_LITERAL(14, 129, 3), // "txt"
QT_MOC_LITERAL(15, 133, 5), // "flags"
QT_MOC_LITERAL(16, 139, 4), // "Free"
QT_MOC_LITERAL(17, 144, 16) // "QDBusReply<void>"

    },
    "OrgFreedesktopAvahiServiceResolverInterface\0"
    "Failure\0\0error\0Found\0interface\0protocol\0"
    "name\0type\0domain\0host\0aprotocol\0address\0"
    "port\0txt\0flags\0Free\0QDBusReply<void>"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OrgFreedesktopAvahiServiceResolverInterface[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       4,   11,   32,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,   55,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QString, QMetaType::UShort, QMetaType::QByteArrayList, QMetaType::UInt,    5,    6,    7,    8,    9,   10,   11,   12,   13,   14,   15,

 // slots: parameters
    0x80000000 | 17,

       0        // eod
};

void OrgFreedesktopAvahiServiceResolverInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OrgFreedesktopAvahiServiceResolverInterface *_t = static_cast<OrgFreedesktopAvahiServiceResolverInterface *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->Failure((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->Found((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< ushort(*)>(_a[9])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[10])),(*reinterpret_cast< uint(*)>(_a[11]))); break;
        case 2: { QDBusReply<void> _r = _t->Free();
            if (_a[0]) *reinterpret_cast< QDBusReply<void>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (OrgFreedesktopAvahiServiceResolverInterface::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OrgFreedesktopAvahiServiceResolverInterface::Failure)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (OrgFreedesktopAvahiServiceResolverInterface::*_t)(int , int , const QString & , const QString & , const QString & , const QString & , int , const QString & , ushort , const QList<QByteArray> & , uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OrgFreedesktopAvahiServiceResolverInterface::Found)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject OrgFreedesktopAvahiServiceResolverInterface::staticMetaObject = {
    { &QDBusAbstractInterface::staticMetaObject, qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface.data,
      qt_meta_data_OrgFreedesktopAvahiServiceResolverInterface,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *OrgFreedesktopAvahiServiceResolverInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAvahiServiceResolverInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OrgFreedesktopAvahiServiceResolverInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAvahiServiceResolverInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAvahiServiceResolverInterface::Failure(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void OrgFreedesktopAvahiServiceResolverInterface::Found(int _t1, int _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, int _t7, const QString & _t8, ushort _t9, const QList<QByteArray> & _t10, uint _t11)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)), const_cast<void*>(reinterpret_cast<const void*>(&_t8)), const_cast<void*>(reinterpret_cast<const void*>(&_t9)), const_cast<void*>(reinterpret_cast<const void*>(&_t10)), const_cast<void*>(reinterpret_cast<const void*>(&_t11)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
