/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p avahi_servicebrowser_interface /usr/src/ports/kf5-kdnssd/kf5-kdnssd-5.43.0-1.x86_64/src/kdnssd-5.43.0/src/org.freedesktop.Avahi.ServiceBrowser.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef AVAHI_SERVICEBROWSER_INTERFACE_H
#define AVAHI_SERVICEBROWSER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Avahi.ServiceBrowser
 */
class OrgFreedesktopAvahiServiceBrowserInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Avahi.ServiceBrowser"; }

public:
    OrgFreedesktopAvahiServiceBrowserInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAvahiServiceBrowserInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Free()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Free"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void AllForNow();
    void CacheExhausted();
    void Failure(const QString &error);
    void ItemNew(int interface, int protocol, const QString &name, const QString &type, const QString &domain, uint flags);
    void ItemRemove(int interface, int protocol, const QString &name, const QString &type, const QString &domain, uint flags);
};

namespace org {
  namespace freedesktop {
    namespace Avahi {
      typedef ::OrgFreedesktopAvahiServiceBrowserInterface ServiceBrowser;
    }
  }
}
#endif
