/****************************************************************************
** Meta object code from reading C++ file 'avahi_server_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdnssd-5.43.0/src/avahi_server_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'avahi_server_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OrgFreedesktopAvahiServerInterface_t {
    QByteArrayData data[61];
    char stringdata0[813];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OrgFreedesktopAvahiServerInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OrgFreedesktopAvahiServerInterface_t qt_meta_stringdata_OrgFreedesktopAvahiServerInterface = {
    {
QT_MOC_LITERAL(0, 0, 34), // "OrgFreedesktopAvahiServerInte..."
QT_MOC_LITERAL(1, 35, 12), // "StateChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 5), // "state"
QT_MOC_LITERAL(4, 55, 5), // "error"
QT_MOC_LITERAL(5, 61, 18), // "AddressResolverNew"
QT_MOC_LITERAL(6, 80, 27), // "QDBusReply<QDBusObjectPath>"
QT_MOC_LITERAL(7, 108, 9), // "interface"
QT_MOC_LITERAL(8, 118, 8), // "protocol"
QT_MOC_LITERAL(9, 127, 7), // "address"
QT_MOC_LITERAL(10, 135, 5), // "flags"
QT_MOC_LITERAL(11, 141, 16), // "DomainBrowserNew"
QT_MOC_LITERAL(12, 158, 6), // "domain"
QT_MOC_LITERAL(13, 165, 5), // "btype"
QT_MOC_LITERAL(14, 171, 13), // "EntryGroupNew"
QT_MOC_LITERAL(15, 185, 13), // "GetAPIVersion"
QT_MOC_LITERAL(16, 199, 16), // "QDBusReply<uint>"
QT_MOC_LITERAL(17, 216, 22), // "GetAlternativeHostName"
QT_MOC_LITERAL(18, 239, 19), // "QDBusReply<QString>"
QT_MOC_LITERAL(19, 259, 4), // "name"
QT_MOC_LITERAL(20, 264, 25), // "GetAlternativeServiceName"
QT_MOC_LITERAL(21, 290, 13), // "GetDomainName"
QT_MOC_LITERAL(22, 304, 11), // "GetHostName"
QT_MOC_LITERAL(23, 316, 15), // "GetHostNameFqdn"
QT_MOC_LITERAL(24, 332, 21), // "GetLocalServiceCookie"
QT_MOC_LITERAL(25, 354, 30), // "GetNetworkInterfaceIndexByName"
QT_MOC_LITERAL(26, 385, 15), // "QDBusReply<int>"
QT_MOC_LITERAL(27, 401, 30), // "GetNetworkInterfaceNameByIndex"
QT_MOC_LITERAL(28, 432, 5), // "index"
QT_MOC_LITERAL(29, 438, 8), // "GetState"
QT_MOC_LITERAL(30, 447, 16), // "GetVersionString"
QT_MOC_LITERAL(31, 464, 19), // "HostNameResolverNew"
QT_MOC_LITERAL(32, 484, 9), // "aprotocol"
QT_MOC_LITERAL(33, 494, 21), // "IsNSSSupportAvailable"
QT_MOC_LITERAL(34, 516, 16), // "QDBusReply<bool>"
QT_MOC_LITERAL(35, 533, 16), // "RecordBrowserNew"
QT_MOC_LITERAL(36, 550, 5), // "clazz"
QT_MOC_LITERAL(37, 556, 4), // "type"
QT_MOC_LITERAL(38, 561, 14), // "ResolveAddress"
QT_MOC_LITERAL(39, 576, 4), // "int&"
QT_MOC_LITERAL(40, 581, 9), // "protocol_"
QT_MOC_LITERAL(41, 591, 8), // "QString&"
QT_MOC_LITERAL(42, 600, 8), // "address_"
QT_MOC_LITERAL(43, 609, 5), // "uint&"
QT_MOC_LITERAL(44, 615, 6), // "flags_"
QT_MOC_LITERAL(45, 622, 15), // "ResolveHostName"
QT_MOC_LITERAL(46, 638, 5), // "name_"
QT_MOC_LITERAL(47, 644, 10), // "aprotocol_"
QT_MOC_LITERAL(48, 655, 14), // "ResolveService"
QT_MOC_LITERAL(49, 670, 5), // "type_"
QT_MOC_LITERAL(50, 676, 7), // "domain_"
QT_MOC_LITERAL(51, 684, 4), // "host"
QT_MOC_LITERAL(52, 689, 7), // "ushort&"
QT_MOC_LITERAL(53, 697, 4), // "port"
QT_MOC_LITERAL(54, 702, 18), // "QList<QByteArray>&"
QT_MOC_LITERAL(55, 721, 3), // "txt"
QT_MOC_LITERAL(56, 725, 17), // "ServiceBrowserNew"
QT_MOC_LITERAL(57, 743, 18), // "ServiceResolverNew"
QT_MOC_LITERAL(58, 762, 21), // "ServiceTypeBrowserNew"
QT_MOC_LITERAL(59, 784, 11), // "SetHostName"
QT_MOC_LITERAL(60, 796, 16) // "QDBusReply<void>"

    },
    "OrgFreedesktopAvahiServerInterface\0"
    "StateChanged\0\0state\0error\0AddressResolverNew\0"
    "QDBusReply<QDBusObjectPath>\0interface\0"
    "protocol\0address\0flags\0DomainBrowserNew\0"
    "domain\0btype\0EntryGroupNew\0GetAPIVersion\0"
    "QDBusReply<uint>\0GetAlternativeHostName\0"
    "QDBusReply<QString>\0name\0"
    "GetAlternativeServiceName\0GetDomainName\0"
    "GetHostName\0GetHostNameFqdn\0"
    "GetLocalServiceCookie\0"
    "GetNetworkInterfaceIndexByName\0"
    "QDBusReply<int>\0GetNetworkInterfaceNameByIndex\0"
    "index\0GetState\0GetVersionString\0"
    "HostNameResolverNew\0aprotocol\0"
    "IsNSSSupportAvailable\0QDBusReply<bool>\0"
    "RecordBrowserNew\0clazz\0type\0ResolveAddress\0"
    "int&\0protocol_\0QString&\0address_\0uint&\0"
    "flags_\0ResolveHostName\0name_\0aprotocol_\0"
    "ResolveService\0type_\0domain_\0host\0"
    "ushort&\0port\0QList<QByteArray>&\0txt\0"
    "ServiceBrowserNew\0ServiceResolverNew\0"
    "ServiceTypeBrowserNew\0SetHostName\0"
    "QDBusReply<void>"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OrgFreedesktopAvahiServerInterface[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  139,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    4,  144,    2, 0x0a /* Public */,
      11,    5,  153,    2, 0x0a /* Public */,
      14,    0,  164,    2, 0x0a /* Public */,
      15,    0,  165,    2, 0x0a /* Public */,
      17,    1,  166,    2, 0x0a /* Public */,
      20,    1,  169,    2, 0x0a /* Public */,
      21,    0,  172,    2, 0x0a /* Public */,
      22,    0,  173,    2, 0x0a /* Public */,
      23,    0,  174,    2, 0x0a /* Public */,
      24,    0,  175,    2, 0x0a /* Public */,
      25,    1,  176,    2, 0x0a /* Public */,
      27,    1,  179,    2, 0x0a /* Public */,
      29,    0,  182,    2, 0x0a /* Public */,
      30,    0,  183,    2, 0x0a /* Public */,
      31,    5,  184,    2, 0x0a /* Public */,
      33,    0,  195,    2, 0x0a /* Public */,
      35,    6,  196,    2, 0x0a /* Public */,
      38,    9,  209,    2, 0x0a /* Public */,
      45,   10,  228,    2, 0x0a /* Public */,
      48,   17,  249,    2, 0x0a /* Public */,
      56,    5,  284,    2, 0x0a /* Public */,
      57,    7,  295,    2, 0x0a /* Public */,
      58,    4,  310,    2, 0x0a /* Public */,
      59,    1,  319,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    3,    4,

 // slots: parameters
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::UInt,    7,    8,    9,   10,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::UInt,    7,    8,   12,   13,   10,
    0x80000000 | 6,
    0x80000000 | 16,
    0x80000000 | 18, QMetaType::QString,   19,
    0x80000000 | 18, QMetaType::QString,   19,
    0x80000000 | 18,
    0x80000000 | 18,
    0x80000000 | 18,
    0x80000000 | 16,
    0x80000000 | 26, QMetaType::QString,   19,
    0x80000000 | 18, QMetaType::Int,   28,
    0x80000000 | 26,
    0x80000000 | 18,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::UInt,    7,    8,   19,   32,   10,
    0x80000000 | 34,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::UShort, QMetaType::UShort, QMetaType::UInt,    7,    8,   19,   36,   37,   10,
    0x80000000 | 26, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::UInt, 0x80000000 | 39, 0x80000000 | 39, 0x80000000 | 41, 0x80000000 | 41, 0x80000000 | 43,    7,    8,    9,   10,   40,   32,   42,   19,   44,
    0x80000000 | 26, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::UInt, 0x80000000 | 39, 0x80000000 | 41, 0x80000000 | 39, 0x80000000 | 41, 0x80000000 | 43,    7,    8,   19,   32,   10,   40,   46,   47,    9,   44,
    0x80000000 | 26, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::UInt, 0x80000000 | 39, 0x80000000 | 41, 0x80000000 | 41, 0x80000000 | 41, 0x80000000 | 41, 0x80000000 | 39, 0x80000000 | 41, 0x80000000 | 52, 0x80000000 | 54, 0x80000000 | 43,    7,    8,   19,   37,   12,   32,   10,   40,   46,   49,   50,   51,   47,    9,   53,   55,   44,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::UInt,    7,    8,   37,   12,   10,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::UInt,    7,    8,   19,   37,   12,   32,   10,
    0x80000000 | 6, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::UInt,    7,    8,   12,   10,
    0x80000000 | 60, QMetaType::QString,   19,

       0        // eod
};

void OrgFreedesktopAvahiServerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OrgFreedesktopAvahiServerInterface *_t = static_cast<OrgFreedesktopAvahiServerInterface *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->StateChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: { QDBusReply<QDBusObjectPath> _r = _t->AddressResolverNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusReply<QDBusObjectPath> _r = _t->DomainBrowserNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusReply<QDBusObjectPath> _r = _t->EntryGroupNew();
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusReply<uint> _r = _t->GetAPIVersion();
            if (_a[0]) *reinterpret_cast< QDBusReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusReply<QString> _r = _t->GetAlternativeHostName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusReply<QString> _r = _t->GetAlternativeServiceName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusReply<QString> _r = _t->GetDomainName();
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusReply<QString> _r = _t->GetHostName();
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusReply<QString> _r = _t->GetHostNameFqdn();
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusReply<uint> _r = _t->GetLocalServiceCookie();
            if (_a[0]) *reinterpret_cast< QDBusReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusReply<int> _r = _t->GetNetworkInterfaceIndexByName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusReply<QString> _r = _t->GetNetworkInterfaceNameByIndex((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusReply<int> _r = _t->GetState();
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusReply<QString> _r = _t->GetVersionString();
            if (_a[0]) *reinterpret_cast< QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusReply<QDBusObjectPath> _r = _t->HostNameResolverNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusReply<bool> _r = _t->IsNSSSupportAvailable();
            if (_a[0]) *reinterpret_cast< QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusReply<QDBusObjectPath> _r = _t->RecordBrowserNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< ushort(*)>(_a[4])),(*reinterpret_cast< ushort(*)>(_a[5])),(*reinterpret_cast< uint(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusReply<int> _r = _t->ResolveAddress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< QString(*)>(_a[8])),(*reinterpret_cast< uint(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusReply<int> _r = _t->ResolveHostName((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])),(*reinterpret_cast< QString(*)>(_a[9])),(*reinterpret_cast< uint(*)>(_a[10])));
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusReply<int> _r = _t->ResolveService((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< uint(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])),(*reinterpret_cast< QString(*)>(_a[9])),(*reinterpret_cast< QString(*)>(_a[10])),(*reinterpret_cast< QString(*)>(_a[11])),(*reinterpret_cast< QString(*)>(_a[12])),(*reinterpret_cast< int(*)>(_a[13])),(*reinterpret_cast< QString(*)>(_a[14])),(*reinterpret_cast< ushort(*)>(_a[15])),(*reinterpret_cast< QList<QByteArray>(*)>(_a[16])),(*reinterpret_cast< uint(*)>(_a[17])));
            if (_a[0]) *reinterpret_cast< QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusReply<QDBusObjectPath> _r = _t->ServiceBrowserNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusReply<QDBusObjectPath> _r = _t->ServiceResolverNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< uint(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusReply<QDBusObjectPath> _r = _t->ServiceTypeBrowserNew((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusReply<void> _r = _t->SetHostName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusReply<void>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (OrgFreedesktopAvahiServerInterface::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OrgFreedesktopAvahiServerInterface::StateChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject OrgFreedesktopAvahiServerInterface::staticMetaObject = {
    { &QDBusAbstractInterface::staticMetaObject, qt_meta_stringdata_OrgFreedesktopAvahiServerInterface.data,
      qt_meta_data_OrgFreedesktopAvahiServerInterface,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *OrgFreedesktopAvahiServerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAvahiServerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OrgFreedesktopAvahiServerInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAvahiServerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAvahiServerInterface::StateChanged(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
