/****************************************************************************
** Meta object code from reading C++ file 'avahi-servicebrowser_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdnssd-5.43.0/src/avahi-servicebrowser_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'avahi-servicebrowser_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate_t {
    QByteArrayData data[8];
    char stringdata0[116];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate_t qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate = {
    {
QT_MOC_LITERAL(0, 0, 29), // "KDNSSD::ServiceBrowserPrivate"
QT_MOC_LITERAL(1, 30, 15), // "browserFinished"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 13), // "queryFinished"
QT_MOC_LITERAL(4, 61, 15), // "serviceResolved"
QT_MOC_LITERAL(5, 77, 7), // "success"
QT_MOC_LITERAL(6, 85, 13), // "gotNewService"
QT_MOC_LITERAL(7, 99, 16) // "gotRemoveService"

    },
    "KDNSSD::ServiceBrowserPrivate\0"
    "browserFinished\0\0queryFinished\0"
    "serviceResolved\0success\0gotNewService\0"
    "gotRemoveService"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDNSSD__ServiceBrowserPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x08 /* Private */,
       3,    0,   40,    2, 0x08 /* Private */,
       4,    1,   41,    2, 0x08 /* Private */,
       6,    6,   44,    2, 0x08 /* Private */,
       7,    6,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::UInt,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::UInt,    2,    2,    2,    2,    2,    2,

       0        // eod
};

void KDNSSD::ServiceBrowserPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServiceBrowserPrivate *_t = static_cast<ServiceBrowserPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->browserFinished(); break;
        case 1: _t->queryFinished(); break;
        case 2: _t->serviceResolved((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->gotNewService((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< uint(*)>(_a[6]))); break;
        case 4: _t->gotRemoveService((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< uint(*)>(_a[6]))); break;
        default: ;
        }
    }
}

const QMetaObject KDNSSD::ServiceBrowserPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate.data,
      qt_meta_data_KDNSSD__ServiceBrowserPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDNSSD::ServiceBrowserPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDNSSD::ServiceBrowserPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDNSSD__ServiceBrowserPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDNSSD::ServiceBrowserPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
